@@ -1,11 +1,11 @@
 from typing import List
 
-from odin_messages.base import BaseEventMessageAssay
+from odin_messages.base import BaseEventMessageArray
 from odin_messages.orders import NewLimitOrderMessage, UpdateLimitOrderMessage
 
 
-class NewLimitOrdersArray(BaseEventMessageAssay):
+class NewLimitOrdersArray(BaseEventMessageArray):
     messages: List[NewLimitOrderMessage]
 
-class UpdateLimitOrdersArray(BaseEventMessageAssay):
+class UpdateLimitOrdersArray(BaseEventMessageArray):
     messages: List[UpdateLimitOrderMessage]
